@@ -8,7 +8,10 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__copyright__ = '(c) 2012 Canonical Ltd.'
+__copyright__ = '''
+(c) 2012 Canonical Ltd.
+(c) 2017 - 2022 Martin Pitt <martin@piware.de>
+'''
 
 import copy
 import functools
@@ -18,6 +21,7 @@ import os
 import sys
 import time
 import types
+from pathlib import Path
 from typing import Optional, Dict, Any, List, Tuple, Sequence, KeysView
 from xml.etree import ElementTree
 
@@ -44,12 +48,13 @@ CallLogType = Tuple[int, str, Sequence[Any]]
 def load_module(name: str):
     '''Load a mock template Python module from dbusmock/templates/'''
 
-    if os.path.exists(name) and os.path.splitext(name)[1] == '.py':
-        spec = importlib.util.spec_from_file_location(os.path.splitext(os.path.basename(name))[0], name)
+    pname = Path(name)
+
+    if pname.exists() and pname.suffix == '.py':
+        spec = importlib.util.spec_from_file_location(pname.stem, name)
         assert spec
         mod = importlib.util.module_from_spec(spec)
-        with open(name, encoding="UTF-8") as f:
-            exec(f.read(), mod.__dict__, mod.__dict__)  # pylint: disable=exec-used
+        exec(pname.read_text("UTF-8"), mod.__dict__, mod.__dict__)  # pylint: disable=exec-used
         return mod
 
     return importlib.import_module('dbusmock.templates.' + name)
@@ -452,7 +457,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
         # mock_method(); using message_keyword with this dynamic approach fails
         # because inspect cannot handle those, so pass on interface and method
         # name as first positional arguments
-        method = lambda self, *args, **kwargs: DBusMockObject.mock_method(
+        method = lambda self, *args, **kwargs: DBusMockObject.mock_method(  # noqa: E731
             self, interface, name, in_sig, *args, **kwargs)
 
         # we cannot specify in_signature here, as that trips over a consistency
@@ -614,7 +619,8 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
 
         args = _convert_args(signature, sigargs)
 
-        sig = dbus.lowlevel.SignalMessage(self.path, interface, name)
+        path = details.get("path", self.path)
+        sig = dbus.lowlevel.SignalMessage(path, interface, name)
         sig.append(*args, signature=signature)
         dest = details.get("destination", None)
         if dest is not None:
@@ -623,7 +629,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
         for location in self.locations:
             conn = location[0]
             conn.send_message(sig)
-        self.log(f'emit {self.path} {interface}.{name}{_format_args(args)}')
+        self.log(f'emit {path} {interface}.{name}{_format_args(args)}')
 
     @dbus.service.method(MOCK_IFACE,
                          in_signature='sssav',
@@ -660,6 +666,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
               "signature"
         details: dictionary with a string key/value entries. Supported keys are:
             "destination": for the signal destination
+            "path": for the object path to send the signal from
         '''
         self._emit_signal(interface, name, signature, sigargs, details)
 
